@@ -43,16 +43,6 @@ def parse(
 
     parser_backend = parser.run(mainfile_path, logger=logger)
 
-    from nomad.metainfo import MSection
-    from nomad.parsing.legacy import Backend
-
-    if isinstance(parser_backend, MSection):
-        backend = Backend(parser._metainfo_env, parser.domain)
-        root_section = str(datamodel.domains[parser.domain]['root_section'])
-        setattr(backend.entry_archive, root_section, parser_backend)
-        backend.resource.add(parser_backend)
-        parser_backend = backend
-
     if not parser_backend.status[0] == 'ParseSuccess':
         logger.error('parsing was not successful', status=parser_backend.status)
 
@@ -73,7 +63,7 @@ def normalize(
             if normalizer_instance.__class__.__name__ == normalizer)
 
     assert normalizer is not None, 'there is no normalizer %s' % str(normalizer)
-    normalizer_instance = typing.cast(typing.Callable, normalizer)(parser_backend)
+    normalizer_instance = typing.cast(typing.Callable, normalizer)(parser_backend.entry_archive)
     logger = logger.bind(normalizer=normalizer_instance.__class__.__name__)
     logger.info('identified normalizer')
 
