@@ -18,10 +18,11 @@ new nomad@fairdi infrastructure. This covers aspects like the new metainfo, a un
 wrapper for parsers, parser logging, and a parser backend.
 '''
 
-from typing import cast, Dict, List, Union, Any, Set, Iterable, Tuple
+from typing import cast, Dict, List, Union, Any, Set, Iterable, Tuple, Type
 import numpy as np
 from pint.errors import UndefinedUnitError
 import os.path
+import importlib
 
 
 from nomadcore.local_meta_info import loadJsonFile, InfoKindEl, InfoKindEnv
@@ -30,7 +31,7 @@ from nomad import utils
 from nomad.units import ureg
 from nomad.metainfo import (
     Definition, SubSection, Package, Quantity, Category, Section, Reference,
-    Environment, MEnum, MSection, DefinitionAnnotation)
+    Environment, MEnum, MSection, DefinitionAnnotation, MetainfoError, MSectionBound)
 
 logger = utils.get_logger(__name__)
 
@@ -105,11 +106,47 @@ class LegacyMetainfoEnvironment(Environment):
     the environment.
     '''
 
+    @staticmethod
+    def from_legacy_package_path(path):
+        metainfo_package_name = os.path.basename(path)
+        package = metainfo_package_name
+        if package.endswith('.nomadmetainfo.json'):
+            package = package[:-19]
+        if package.endswith('.json'):
+            package = package[:-5]
+
+        python_package_name, _ = python_package_mapping(package)
+        python_package_name = '.'.join(python_package_name.split('.')[:-1])
+        python_module = importlib.import_module(python_package_name)
+        metainfo = getattr(python_module, 'm_env')
+
+        return metainfo
+
     legacy_package_name = Quantity(type=str)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.__section_to_sub_section_name = None
+        self.__legacy_names = None
+
+    def from_legacy_name(self, name: str, section_cls: Type[MSectionBound]) -> MSectionBound:
+        ''' Returns the definition of the given globally unique legacy metainfo name. '''
+        if self.__legacy_names is None:
+            self.__legacy_names = dict()
+            for definition in self.m_all_contents():
+                try:
+                    if isinstance(definition, Section):
+                        if definition.extends_base_section:
+                            continue
+                    legacy = definition.a_legacy
+                    key = (legacy.name, definition.m_def.section_cls)
+                    if key in self.__legacy_names:
+                        raise MetainfoError('Legacy name %s is not globally unique' % legacy.name)
+                    self.__legacy_names[key] = definition
+                except AttributeError:
+                    pass
+
+        return self.__legacy_names.get((name, section_cls))
 
     @property
     def section_to_sub_section_name(self) -> Dict[str, str]:
