@@ -23,7 +23,7 @@ from elasticsearch.exceptions import NotFoundError
 from datetime import datetime
 import json
 
-from nomad import config, datamodel, infrastructure, datamodel, utils
+from nomad import config, datamodel, infrastructure, utils
 from nomad.metainfo.search_extension import search_quantities, metrics, order_default_quantities
 
 
@@ -753,30 +753,3 @@ def flat(obj, prefix=None):
         return result
     else:
         return obj
-
-
-if __name__ == '__main__':
-    # Due to this import, the parsing module will register all code_names based on parser
-    # implementations.
-    from nomad import parsing  # pylint: disable=unused-import
-    import json
-
-    def to_dict(search_quantity):
-        result = {
-            'name': search_quantity.qualified_name,
-            'description': search_quantity.description,
-            'many': search_quantity.many,
-        }
-
-        if search_quantity.statistic_fixed_size is not None:
-            result['statistic_size'] = search_quantity.statistic_fixed_size
-        if search_quantity.statistic_values is not None:
-            result['statistic_values'] = search_quantity.statistic_values
-
-        return result
-
-    export = {
-        search_quantity.qualified_name: to_dict(search_quantity)
-        for search_quantity in search_quantities.values()
-    }
-    print(json.dumps(export, indent=2))
